@@ -13,9 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from http import client as http_client
 import logging
-import re
 import time
 from urllib import parse as urlparse
 
@@ -28,7 +26,7 @@ from sushy import utils
 LOG = logging.getLogger(__name__)
 
 
-_SERVER_SIDE_RETRIES = 10
+_SERVER_SIDE_RETRIES = 5
 _SERVER_SIDE_RETRY_DELAY = 3
 
 
@@ -52,15 +50,6 @@ class Connector(object):
         # By default, we ask HTTP server to shut down HTTP connection we've
         # just used.
         self._session.headers['Connection'] = 'close'
-        # NOTE(TheJulia): Depending on the BMC, offering compression as an
-        # acceptable response changes the ETag behavior to offering an
-        # automatic "weak" ETag response, which is appropriate because the
-        # body content *may* not be a byte for byte match given compression.
-        # Overall, the value of compression is less than the value of concise
-        # interaction with the BMC. Setting to identity basically means
-        # "without modification or compression". By default, python-requests
-        # indicates responses can be compressed.
-        self._session.headers['Accept-Encoding'] = 'identity'
 
         if username or password:
             LOG.warning('Passing username and password to Connector is '
@@ -86,15 +75,6 @@ class Connector(object):
         """Close this connector and the associated HTTP session."""
         self._session.close()
 
-    def check_retry_on_exception(self, exception_msg):
-        """Checks whether retry on exception is required."""
-        if ('SYS518' in str(exception_msg)):
-            LOG.debug('iDRAC is not yet ready after previous operation. '
-                      'Error: %(err)s', {'err': str(exception_msg)})
-            return True
-        else:
-            return False
-
     def _op(self, method, path='', data=None, headers=None, blocking=False,
             timeout=60, server_side_retries=_SERVER_SIDE_RETRIES,
             **extra_session_req_kwargs):
@@ -106,11 +86,7 @@ class Connector(object):
         :param data: Optional JSON data.
         :param headers: Optional dictionary of headers.
         :param blocking: Whether to block for asynchronous operations.
-        :param timeout: Max time in seconds to wait for blocking async call or
-                        for requests library to connect and read. If a custom
-                        timeout for requests is provided in
-                        extra_session_req_kwargs, it will be used instead for
-                        those calls.
+        :param timeout: Max time in seconds to wait for blocking async call.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -139,16 +115,8 @@ class Connector(object):
         try:
             response = self._session.request(method, url, json=data,
                                              headers=headers,
-                                             timeout=timeout,
                                              **extra_session_req_kwargs)
-        except requests.exceptions.RequestException as e:
-            # Capture any general exception by looking for the parent
-            # class of exceptions in the requests library.
-            # Specifically this will cover cases such as transport
-            # failures, connection timeouts, and encoding errors.
-            # Raising this as sushy ConnectionError allows users to
-            # understand something bad has happened, and to
-            # allow them to respond accordingly.
+        except requests.ConnectionError as e:
             raise exceptions.ConnectionError(url=url, error=e)
 
         if self._response_callback:
@@ -197,7 +165,6 @@ class Connector(object):
                     response = self._session.request(
                         method, url, json=data,
                         headers=headers,
-                        timeout=timeout,
                         **extra_session_req_kwargs)
                 except exceptions.HTTPError as retry_exc:
                     LOG.error("Failure occured while attempting to retry "
@@ -214,9 +181,9 @@ class Connector(object):
                               "%s", e.message)
                 raise
         except exceptions.ServerSideError as e:
-            if ((method.lower() == 'get'
-                or self.check_retry_on_exception(e.message))
-                    and server_side_retries > 0):
+            if method.lower() != 'get' or server_side_retries <= 0:
+                raise
+            else:
                 LOG.warning('Got server side error %s in response to a '
                             'GET request, retrying after %d seconds',
                             e, _SERVER_SIDE_RETRY_DELAY)
@@ -225,8 +192,6 @@ class Connector(object):
                                 blocking=blocking, timeout=timeout,
                                 server_side_retries=server_side_retries - 1,
                                 **extra_session_req_kwargs)
-            else:
-                raise
 
         if blocking and response.status_code == 202:
             if not response.headers.get('Location'):
@@ -287,93 +252,13 @@ class Connector(object):
                         blocking=blocking, timeout=timeout,
                         **extra_session_req_kwargs)
 
-    def _etag_handler(self, path='', data=None, headers=None, etag=None,
-                      blocking=False, timeout=60, **extra_session_req_kwargs):
-        """eTag handler containing workarounds for PATCH requests with eTags.
-
-        :param path: Optional sub-URI path to the resource.
-        :param data: Optional JSON data.
-        :param headers: Optional dictionary of headers.
-        :param etag: eTag string.
-        :param blocking: Whether to block for asynchronous operations.
-        :param timeout: Max time in seconds to wait for blocking async call.
-        :param extra_session_req_kwargs: Optional keyword argument to pass
-         requests library arguments which would pass on to requests session
-         object.
-        :returns: The response object from the requests library.
-        :raises: ConnectionError
-        :raises: HTTPError
-        """
-        if etag is not None:
-            if not headers:
-                headers = {}
-            headers['If-Match'] = etag
-        try:
-            response = self._op('PATCH', path, data=data,
-                                headers=headers,
-                                blocking=blocking, timeout=timeout,
-                                **extra_session_req_kwargs)
-        except exceptions.HTTPError as resp:
-            LOG.warning("Initial request with eTag failed: %s",
-                        resp)
-            if resp.status_code == http_client.PRECONDITION_FAILED:
-                # NOTE(janders) if there was no eTag provided AND the response
-                # is HTTP 412 Precondition Failed, raise the exception
-                if not etag:
-                    raise
-                # checking for weak eTag
-                pattern = re.compile(r'^(W\/)("\w*")$')
-                match = pattern.match(etag)
-                if match:
-                    LOG.info("Weak eTag provided with original request to "
-                             "%s. Attempting to conversion to strong eTag "
-                             "and re-trying.", path)
-                    # trying weak eTag converted to strong
-                    headers['If-Match'] = match.group(2)
-                    try:
-                        response = self._op('PATCH', path, data=data,
-                                            headers=headers,
-                                            blocking=blocking,
-                                            timeout=timeout,
-                                            **extra_session_req_kwargs)
-                    except exceptions.HTTPError as resp:
-                        if (resp.status_code == http_client.
-                           PRECONDITION_FAILED):
-                            LOG.warning("Request to %s with weak eTag "
-                                        "converted to strong eTag also "
-                                        "failed. Making the final attempt "
-                                        "with no eTag specified.", path)
-                        response = None
-                    if response:
-                        return response
-                else:
-                    # eTag is strong, if it failed the only other thing
-                    # to try is removing it entirely
-                    # info
-                    LOG.warning("Strong eTag provided - retrying request to "
-                                "%s with eTag removed.", path)
-                del headers['If-Match']
-                try:
-                    response = self._op('PATCH', path, data=data,
-                                        headers=headers,
-                                        blocking=blocking, timeout=timeout,
-                                        **extra_session_req_kwargs)
-                except exceptions.HTTPError as resp:
-                    LOG.error("Final re-try with eTag removed has failed, "
-                              "raising exception %s", resp)
-                    raise
-            else:
-                raise
-        return response
-
-    def patch(self, path='', data=None, headers=None, etag=None,
-              blocking=False, timeout=60, **extra_session_req_kwargs):
+    def patch(self, path='', data=None, headers=None, blocking=False,
+              timeout=60, **extra_session_req_kwargs):
         """HTTP PATCH method.
 
         :param path: Optional sub-URI path to the resource.
         :param data: Optional JSON data.
         :param headers: Optional dictionary of headers.
-        :param etag: Optional eTag string.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call.
         :param extra_session_req_kwargs: Optional keyword argument to pass
@@ -383,10 +268,9 @@ class Connector(object):
         :raises: ConnectionError
         :raises: HTTPError
         """
-        return self._etag_handler(path, data,
-                                  headers, etag,
-                                  blocking, timeout,
-                                  **extra_session_req_kwargs)
+        return self._op('PATCH', path, data=data, headers=headers,
+                        blocking=blocking, timeout=timeout,
+                        **extra_session_req_kwargs)
 
     def put(self, path='', data=None, headers=None, blocking=False,
             timeout=60, **extra_session_req_kwargs):
